package com.blazinggames.retro.modern.search;

// Java imports
import java.awt.*;

// URCL imports
import com.blazinggames.urcl.ui.*;
import com.blazinggames.urcl.ui.comp.*;
import com.blazinggames.urcl.ui.sprite.*;

// Retro imports
import com.blazinggames.retro.modern.Title;

/**
 * Ultimate Retro Project Episode 8: Modern Artillery Battle
 * Copyright (C) 2001, 2003-2004 Blazing Games Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * @version 1.00OSR
 * @author Billy D. Spelchan
*/
public class ArtilleryTitle 
extends Title
{
// *********************
// ***** CONSTANTS *****
// *********************

    // Artillery title specific 
    private static final String PLAYERROWS = "08PLAYERROWS";
    private static final String PLAYERCOLS = "08PLAYERCOLS";
    private static final String SOUNDCHECKBOX = "08SOUNDCHECKBOX";
    private static final String AIQUITCHECKBOX = "08AIQUITCHECKBOX";
    private static final String LANDSCAPESELECT = "08LANDSCAPESELECT";
    
    // Shared constants (also used by ArtilleryDisplay)
    private static final String NUMPLAYERS = "08NUMPLAYERS";
    private static final String PLAYERCOLORS = "08PLAYERCOLOR";
    private static final String PLAYERNAME = "08PLAYERNAME";
    private static final String NUMLANDSCAPES = "08NUMLANDSCAPES";
    private static final String LANDNAME = "08LANDNAME";

    
// *********************
// ***** VARIABLES *****
// *********************

    protected int _playerRows[];
    protected int _playerCols[];
    protected SRadioButton _radioButtons[];
    protected SRadioContainer _playerContainers[];
    protected SLabel _playerLabels[];
    protected SCheckbox _soundCheckbox;
    protected SCheckbox _aiCheckbox;
    protected int _numLandscapes;
    protected SRadioButton _landscapes[];
    protected SRadioContainer _landscapeContainer;

// ***********************
// ***** CONSTRUCTOR *****
// ***********************    

    public ArtilleryTitle()
    {
        super();
    }


    public ArtilleryTitle(String pref)
    {
        super(pref);
    }


// *****************************************
// ***** METHODS - Initialization aids *****
// *****************************************

    public void prepareRadioButtons()
    {
        Container c = _displayHandler.getContainer();
        Color pcolor;
        int n = _config.getIntProperty(NUMPLAYERS, 2);
        int temp;
        String tempName;
        
        _radioButtons = new SRadioButton[n * 4];
        _playerContainers = new SRadioContainer[n];
        _playerLabels = new SLabel[n];
    
        for (int cntr = 0; cntr < n; ++cntr) 
        {
            _playerContainers[cntr] = new SRadioContainer();
            temp = 5 * (cntr % 2) + 1;
            tempName = _config.getStringProperty(
                        PLAYERNAME + "[" + cntr + "]", "Player " + (cntr + 1));
            _playerLabels[cntr] = new SLabel(c, tempName, 
                        _playerCols[temp-1], _playerRows[cntr/2],
                        _playerCols[temp]-_playerCols[temp-1],
                        _playerRows[1]-_playerRows[0]);
            pcolor = _config.getColorProperty(PLAYERCOLORS + "[" + cntr + "]", Color.white);
            _playerLabels[cntr].setFontColor(pcolor);
            _playerLabels[cntr].setSolid(false);
            for (int cntrRB = 0; cntrRB < 4; ++cntrRB) 
            {
                _radioButtons[cntr*4+cntrRB] = new SRadioButton(c, "", _playerCols[temp+cntrRB],
                                        _playerRows[cntr/2]);
                _radioButtons[cntr*4+cntrRB].setForeground(pcolor);
                _radioButtons[cntr*4+cntrRB].setBackground(Color.black);
                _playerContainers[cntr].addRadioButton(_radioButtons[cntr*4+cntrRB]);
            } 
        }
    }

    private void prepareCheckboxes()
    {
        Container c = _displayHandler.getContainer();

        String args[] = _config.parseString(_config.getStringProperty(SOUNDCHECKBOX, "x"), ',');
        if (args.length != 3)
        {
            _soundCheckbox = new SCheckbox(c, "SOUND", 100, 440);
        }
        else
        {
            _soundCheckbox = new SCheckbox(c, args[0], _config.parseInt(args[1], 100),
                        _config.parseInt(args[2], 440) );
        }

        args = _config.parseString(_config.getStringProperty(AIQUITCHECKBOX, "x"), ',');
        if (args.length != 3)
        {
            _aiCheckbox = new SCheckbox(c, "AI Quit", 100, 440);
        }
        else
        {
            _aiCheckbox = new SCheckbox(c, args[0], _config.parseInt(args[1], 100),
                        _config.parseInt(args[2], 440) );
        }
        _aiCheckbox.setState(1);
    }
    
    private void prepareLandscapes()
    {
        Container c = _displayHandler.getContainer();

        _numLandscapes = _config.getIntProperty(NUMLANDSCAPES, 1);
        _landscapeContainer = new SRadioContainer();
        
        Rectangle rect = _config.getRectangleProperty(LANDSCAPESELECT, null);
        int w = rect.width / _numLandscapes;
        _landscapes = new SRadioButton[_numLandscapes];
        for (int cntr = 0; cntr < _numLandscapes; ++cntr)
        {
            _landscapes[cntr] = new SRadioButton(c, 
                        _config.getStringProperty(LANDNAME + "[" + cntr + "]", "x"),
                        rect.x + w * cntr, rect.y);
            _landscapeContainer.addRadioButton(_landscapes[cntr]);
        }
    }


// **********************************
// ***** METHODS - From Display *****
// **********************************

    public boolean initialize(DisplayHandler dh)
    {
        super.initialize(dh);

        int cntr;
        String args[] = _config.parseString(_config.getStringProperty(PLAYERROWS, "0"), ',');
        _playerRows = new int[args.length];
        for (cntr = 0; cntr < args.length; ++cntr)
            _playerRows[cntr] = _config.parseInt(args[cntr], 0);
    
        args = _config.parseString(_config.getStringProperty(PLAYERCOLS, "0"), ',');
        _playerCols = new int[args.length];
        for (cntr = 0; cntr < args.length; ++cntr)
            _playerCols[cntr] = _config.parseInt(args[cntr], 0);
    
        prepareRadioButtons();
        prepareCheckboxes();
        prepareLandscapes();
        
        return true;
    }
    
    public void mouse_move(int x, int y, boolean b)
    {
        boolean repaint = false;
        int cntr;

        for (cntr = 0; cntr < _buttons.length; ++cntr)
        {
            repaint |= _buttons[cntr].mouse_move(x, y, b);
        }
        for (cntr = 0; cntr < _playerContainers.length; ++cntr)
        {
            repaint |= _playerContainers[cntr].mouse_move(x, y, b);
        }
        repaint |= _landscapeContainer.mouse_move(x, y, b);
        repaint |= _soundCheckbox.mouse_move(x, y, b);
        repaint |= _aiCheckbox.mouse_move(x, y, b);
        
        if (repaint)
        {
            _displayHandler.refreshDisplay(this);
        }
    }
    
    public void mouse_down(int x, int y)
    {
        boolean repaint = false;
        int cntr;

        for (cntr = 0; cntr < _buttons.length; ++cntr)
        {
            repaint |= _buttons[cntr].mouse_down(x, y);
        }
        for (cntr = 0; cntr < _playerContainers.length; ++cntr)
        {
            repaint |= _playerContainers[cntr].mouse_down(x, y);
        }
        repaint |= _landscapeContainer.mouse_down(x, y);
        repaint |= _soundCheckbox.mouse_down(x, y);
        repaint |= _aiCheckbox.mouse_down(x, y);
        
        if (repaint)
        {
            _displayHandler.refreshDisplay(this);
        }
    }

    public void mouse_up(int x, int y)
    {
        boolean repaint = false;
        int cntr;

        for (cntr = 0; cntr < _buttons.length; ++cntr)
        {
            if (_buttons[cntr].mouse_up(x, y))
            {
                _displayHandler.displayEvent(this, _buttonActions[cntr]);
                repaint = true;
            }
        }
        for (cntr = 0; cntr < _playerContainers.length; ++cntr)
        {
            repaint |= _playerContainers[cntr].mouse_up(x, y);
        }
        repaint |= _landscapeContainer.mouse_up(x, y);
        repaint |= _soundCheckbox.mouse_up(x, y);
        repaint |= _aiCheckbox.mouse_up(x, y);
        
        if (repaint)
        {
            _displayHandler.refreshDisplay(this);
        }
    }
    
    public synchronized void render(Graphics g, Component comp)
    {
        super.render(g, comp);
        int cntr;
        
        for (cntr = 0; cntr < _playerContainers.length; ++cntr) 
        {
            _playerContainers[cntr].render(g, comp);
            _playerLabels[cntr].render(g, comp);
        }
        _soundCheckbox.render(g, comp);
        _aiCheckbox.render(g, comp);
        for (cntr = 0; cntr < _numLandscapes; ++cntr)
        {
            _landscapes[cntr].render(g, comp);
        }
    }


// ***************************************************************************
// ***** METHODS - Additional information getting (setting done by user) *****
// ***************************************************************************

    public int getPlayerType(int id)
    {
        return _playerContainers[id].getButton();
    }
    
    public int getLandscape()
    {
        return _landscapeContainer.getButton();
    }
    
    public boolean getSound()
    {
        return (_soundCheckbox.getState() == 1);
    }
    
    public boolean getAIQuit()
    {
        return (_aiCheckbox.getState() == 1);
    }
}

