package com.blazinggames.retro.modern.search;

// Java imports
import java.awt.*;
import java.awt.image.*;

// Spelchan Imports
import com.blazinggames.urcl.ui.playfield.*;

/**
 * Ultimate Retro Project Episode 8: Modern Artillery Battle
 * Copyright (C) 2001, 2003-2004 Blazing Games Inc.
 *
 * This is useful for animated tiles and in cases where the tile is used as
 * part of an image (background tiles for instance). The attribute determins
 * the image that is shown with the frames being stored in a l-r,t-b grid.
 *
 * In an attempt to improve the speed of the rendering, I am pre-clipping all
 * the tiles and rendering them without scaling.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @author Billy D. Spelchan
 * @version 1.00.020219
 */
public class ImageStripClipped
extends TileRenderer
{
    // *********************
    // ***** VARIABLES *****
    // *********************

    protected Image _imagestrip;
    protected Image _clips[];


    // ************************
    // ***** CONSTRUCTORs *****
    // ************************

    public ImageStripClipped()
    {
        super();
        _imagestrip = null;
    }

    public ImageStripClipped(Container c, Image i, int w, int h)
    {
        super(w, h);
        _imagestrip = i;

        Graphics gTemp;
        int cols = Math.max(1, i.getWidth(c) / w);
        int rows = Math.max(1, i.getHeight(c) / h);
        int numTiles = cols * rows;
        int sxoff, syoff;

        _clips = new Image[numTiles];

        for (int cntr = 0; cntr < numTiles; ++cntr)
        {
            _clips[cntr] = c.createImage(w, h);
            gTemp = _clips[cntr].getGraphics();
            sxoff = (cntr % cols) * w;
            syoff = (cntr / cols) * h;
            gTemp.drawImage(i, 0, 0, w, h,
                            sxoff, syoff, sxoff+w, syoff+h, _backfill, c);
        }

    }


    // *******************************
    // ***** METHODS - RENDERING *****
    // *******************************

    public void render(Graphics g, Component c, int x, int y, int state)
    {
        int tileID = state % _clips.length;

        g.drawImage(_clips[tileID], x, y, _backfill, c);
    }

}
